@@ -21,23 +21,26 @@ speed up
 """
 
 
-def main(pdb, pdb_file, qc, ic, config):
+def main(pdb, pdb_file, qc, ic, config,foldx, evoef):
     os.makedirs(f"output/{pdb}/mutants/", exist_ok=True)
     os.makedirs(f"tmp/", exist_ok=True)
 
     #wildtype analysis:
     intercaat_wt_scores : dict = {} # {position: [intercaat_wt_score]}
     intercaat_result = intercaatWT(pdb_file, qc, ic)
-    evo_wt_score = EvoEF_run(pdb_file, qc, ic)
-    foldx_wt_score = Foldx_run(pdb_file, qc, ic)
+    if evoef:
+        evo_wt_score = EvoEF_run(pdb_file, qc, ic)
+    else:
+        evo_wt_score = "None"
+    if foldx:
+        foldx_wt_score = Foldx_run(pdb_file, qc, ic)
+    else:
+        foldx_wt_score = "None"
     wt_gbsa   = GBSA(pdb_file, qc, ic )
     mutant_folder = f"output/{pdb}/mutants/"
 
     positions_and_mutations = configManager(config, intercaat_result)
 
-    print(positions_and_mutations)
-
-    # print(positions_and_mutations)
     #perform mutation:
     jobs : list = []
     for position in positions_and_mutations:
@@ -77,11 +80,15 @@ def main(pdb, pdb_file, qc, ic, config):
     return df
 
 def mutantEnergyScorer(params):
+    evoef = 0
+    foldx = 0
     position, mutant_name, wt_AA, respos, mutantfile,foldx_wt_score, evo_wt_score,intercaat_wt_scores, mutant_folder, qc, ic,mutant_AA, pdb_file , wt_gbsa = params
     # print(mutant_name)
-    evoef = EvoEF_run(mutantfile, qc, ic, evo_wt_score)
+    if evo_wt_score == "None":
+        evoef = EvoEF_run(mutantfile, qc, ic, evo_wt_score)
     mutant_pdb = mutantfile.split("/")[-1]
-    foldx = Foldx_run(mutant_pdb, qc,ic, mutant_folder,foldx_wt_score)
+    if foldx_wt_score == "None":
+        foldx = Foldx_run(mutant_pdb, qc,ic, mutant_folder,foldx_wt_score)
     dintercaat, contacts = intercaatMutant(position, mutant_pdb, qc, ic, mutant_folder, intercaat_wt_scores, wt_AA, mutant_AA )
     md_energy = GBSA(mutantfile, qc, ic, wt_gbsa )
     return mutant_name, foldx, evoef, dintercaat, contacts, md_energy
@@ -98,6 +105,6 @@ def configManager(config, intercaat_result):
 
 
 def EESMHM():
-    pdb, pdb_file, qc, ic, config = cli()
-    df = main(pdb,pdb_file, qc, ic, config)
+    pdb, pdb_file, qc, ic, config, foldx, evoef = cli()
+    df = main(pdb,pdb_file, qc, ic, config, foldx, evoef)
     return
